@@ -33,12 +33,12 @@
 #' by the \pkg{multcomp} package.
 #' 
 #' \code{emm} is meant to be called only \emph{from} \code{"glht"} as its second
-#' (\code{linfct}) argument. It works similarly to \code{\link[multcomp]{mcp}},
+#' (\code{linfct}) argument. It works similarly to \code{\link[multcomp:glht]{mcp}},
 #' except with \code{specs} (and optionally \code{by} and \code{contr}
 #' arguments) provided as in a call to \code{\link{emmeans}}.
 #' 
 #' @rdname glht-support
-#' @aliases glht-support
+#' @aliases glht-support glht.emmGrid glht.emmlf modelparm.emmwrap
 #' @param ... In \code{emm}, the \code{specs}, \code{by}, and \code{contr}
 #'   arguments you would normally supply to \code{\link{emmeans}}. Only
 #'   \code{specs} is required. Otherwise, arguments that are passed to other
@@ -54,9 +54,7 @@ emm <- function(...) {
 }
 
 # New S3 method for emmlf objects
-#' @importFrom multcomp glht
-#' @method glht emmlf
-#' @export
+#' @export glht.emmlf
 glht.emmlf <- function(model, linfct, ...) {
     # Pass the arguments we should pass to ref_grid:
     args = linfct
@@ -68,14 +66,13 @@ glht.emmlf <- function(model, linfct, ...) {
     if (is.list(emmo)) 
         emmo = emmo[[length(emmo)]]
     # Then call the method for emmo objject
-    glht(model, emmo, ...)
+    glht.emmGrid(model, emmo, ...)
 }
 
 
 # S3 method for an emmGrid object
 # Note: model is redundant, really, so can be omitted
-#' @method glht emmGrid
-#' @export
+#' @export glht.emmGrid
 glht.emmGrid <- function(model, linfct, by, ...) {
     if (!requireNamespace("multcomp"))
         stop(sQuote("glht")," requires ", dQuote("multcomp"), " to be installed")
@@ -86,6 +83,7 @@ glht.emmGrid <- function(model, linfct, by, ...) {
     # add a df value if not supplied
     if (is.null(args$df)) {
         df = summary(linfct)$df
+        df[is.infinite(df)] = NA
         if(any(!is.na(df))) {
             args$df = max(1, as.integer(mean(df, na.rm=TRUE) + .25))
             if (any(args$df != df))
@@ -142,7 +140,6 @@ glht.emmGrid <- function(model, linfct, by, ...) {
 #'   where that is not true, a message is displayed that shows what df is used.
 #'   The user may override this via the \code{df} argument.
 #' 
-#' @export
 #' @examples
 #' require(multcomp)
 #' 
@@ -174,7 +171,7 @@ as.glht.default <- function(object, ...)
 #' @method as.glht emmGrid
 #' @export
 as.glht.emmGrid <- function(object, ...)
-    glht( , object, ...)   # 1st arg not necessary
+    glht.emmGrid( , object, ...)   # 1st arg not necessary
 
 #' @method as.glht emm_list
 #' @export
@@ -183,9 +180,7 @@ as.glht.emm_list <- function(object, ..., which = 1)
 
 
 # S3 modelparm method for emmwrap (S3 wrapper for an emmGrid obj - see glht.emmGrid)
-#' @importFrom multcomp modelparm
-#' @method modelparm emmwrap
-#' @export
+#' @export modelparm.emmwrap
 modelparm.emmwrap <- function(model, coef., vcov., df, ...) {
     object = model$object
     if (is.null(object@misc$estHook)) {
@@ -196,7 +191,7 @@ modelparm.emmwrap <- function(model, coef., vcov., df, ...) {
         bhat = predict(object)
         V = vcov(object)
     }
-    if(missing(df) || is.na(df))
+    if(missing(df) || is.na(df) || is.infinite(df))
         df = 0
     .cls.list("modelparm", coef = bhat, vcov = V,
                 df = df, estimable = !is.na(bhat))
